


%% Endogenous variables and exogenous shocks 
var i m y pi s d;
varexo eps_m eps_s eps_d ;

%% Parameterisation 
parameters  phi_pi phi_y rho_d rho_m rho_s sigma beta lambda;

rho_d  = 0.6;
rho_m  = 0.8;
rho_s  = 0.4;

sigma  = 1;
beta   = 0.99;
lambda = 0.1;

phi_pi = 1.5;
phi_y  = 0.2;

varobs y pi i;


%% Model

model(linear);
  y  =  y(+1)-1/sigma*(i-pi(+1)+log(beta))+d;   /*Dynamic IS curve*/
  pi =  beta*pi(+1)+lambda*(y+m);               /*NKPC*/
  i  =  phi_pi*pi+phi_y*y+s;                    /*Taylor rule*/

  d  =  rho_d*d(-1)+eps_d;                    /*Demand shocks*/
  m  =  rho_m*m(-1)+eps_m;                    /*Output shocks*/
  s  =  rho_s*s(-1)+eps_s;                    /*Monetary shocks*/
end; 




shocks;
var eps_d = 0.1^2;
var eps_m = 0.1^2;
var eps_s = 0.1^2;
end;

steady;
check;

estimated_params;
sigma, gamma_pdf, 1, 0.01;
beta, beta_pdf, 0.99, 0.1; 
lambda, gamma_pdf, 0.75, 0.1; 
phi_pi, gamma_pdf, 1.5, 0.1;
phi_y, gamma_pdf, 1.1, 0.1;
rho_d, beta_pdf, 0.65, 0.1; 
rho_m,  beta_pdf, 0.45, 0.1; 
rho_s,  beta_pdf, 0.85, 0.1; 
%eps_m, inv_gamma_pdf, 0.01, 1;
%eps_s, inv_gamma_pdf, 0.01, 1;
%eps_d, inv_gamma_pdf, 0.01, 1;
end;

identification;








%% Estimation
%estimation(datafile=Ex4_c, mode_check, prefilter=0, order=1,bayesian_irf,plot_priors=1, conf_sig=0.90) y pi i d m s;
%estimation(datafile=Ex4_c,bayesian_irf,irf=40,first_obs=1,mh_replic=2000,
%     mh_nblocks=8,mh_jscale=0.8,mode_compute=1,order=1, moments_varendo, forecast=8, aim_solver) y pi i m d s;
estimation(datafile=Ex4_c, mode_check, plot_priors=1,prefilter=0, order=1, mode_compute=6) y pi i d m s;



